/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/

package org.apache.samza.sql.fn;

import java.util.List;
import org.apache.samza.config.Config;
import org.apache.samza.sql.udfs.ScalarUdf;


public class FlattenUdf implements ScalarUdf<Object> {
  @Override
  public void init(Config udfConfig) {
  }

  public Object execute(Object... arg) {
    List value = (List) arg[0];
    return value != null && !value.isEmpty() ? value.get(0) : value;
  }
}